package de.deversmann.domain;

import org.junit.jupiter.api.Test;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;

import static org.junit.jupiter.api.Assertions.*;

class CSVReaderTest {

    @Test
    void testReadPuzzleWithSolutionRealData() throws IOException {
        String csvContent = """
                4,5,6,7
                8,9,10,11
                12,13,14,15
                16,17,18,19
                //Lösung
                2,2
                3,3
                """;
        Path tempFile = Files.createTempFile("realPuzzle", ".csv");
        Files.writeString(tempFile, csvContent);

        CSVReader reader = new CSVReader();
        PuzzleData data = reader.readPuzzleWithSolution(tempFile.toString());

        int[][] expectedPuzzle = {
                {4, 5, 6, 7},
                {8, 9, 10, 11},
                {12, 13, 14, 15},
                {16, 17, 18, 19}
        };
        assertArrayEquals(expectedPuzzle, data.getPuzzle());
        assertEquals(2, data.getSolutionCoordinates().size());
        assertArrayEquals(new int[]{2, 2}, data.getSolutionCoordinates().get(0));
        assertArrayEquals(new int[]{3, 3}, data.getSolutionCoordinates().get(1));

        Files.delete(tempFile);
    }

    @Test
    void testReadPuzzleWithInvalidData() throws IOException {
        String csvContent = """
                1,2,3
                4,5
                //Lösung
                a,b
                """;
        Path tempFile = Files.createTempFile("invalidPuzzle", ".csv");
        Files.writeString(tempFile, csvContent);

        CSVReader reader = new CSVReader();

        assertThrows(NumberFormatException.class, () -> reader.readPuzzleWithSolution(tempFile.toString()));

        Files.delete(tempFile);
    }

    @Test
    void testReadPuzzleWithoutSolution() throws IOException {
        String csvContent = """
                1,2,3
                4,5,6
                7,8,9
                """;
        Path tempFile = Files.createTempFile("noSolutionPuzzle", ".csv");
        Files.writeString(tempFile, csvContent);

        CSVReader reader = new CSVReader();
        PuzzleData data = reader.readPuzzleWithSolution(tempFile.toString());

        assertNotNull(data.getPuzzle());
        assertTrue(data.getSolutionCoordinates().isEmpty());

        Files.delete(tempFile);
    }
}