package de.deversmann.domain;

import org.junit.jupiter.api.Test;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.List;

import static org.junit.jupiter.api.Assertions.*;

class HighscoreManagerTest {

    @Test
    void testAddAndRetrieveHighscores() {
        HighscoreManager manager = new HighscoreManager();
        manager.addHighscore("Puzzle1", "Alice", 120, 2);

        List<HighscoreEntry> highscores = manager.getHighscores("Puzzle1");

        assertEquals(1, highscores.size());
        assertEquals("Alice", highscores.get(0).getPlayerName());
        assertEquals(120, highscores.get(0).getTimeSeconds());
        assertEquals(2, highscores.get(0).getErrorCount());
    }

    @Test
    void testSaveAndLoadHighscores() throws IOException {
        HighscoreManager manager = new HighscoreManager();
        manager.addHighscore("Puzzle1", "Alice", 120, 2);

        Path tempFile = Files.createTempFile("testHighscores", ".txt");
        manager.saveSinglePuzzle("Puzzle1", tempFile.toString());

        HighscoreManager newManager = new HighscoreManager();
        newManager.loadSinglePuzzle("Puzzle1", tempFile.toString());

        List<HighscoreEntry> highscores = newManager.getHighscores("Puzzle1");

        assertEquals(1, highscores.size());
        assertEquals("Alice", highscores.get(0).getPlayerName());
        assertEquals(120, highscores.get(0).getTimeSeconds());
        assertEquals(2, highscores.get(0).getErrorCount());

        Files.delete(tempFile);
    }

    @Test
    void testGetAverageTimeNoEntries() {
        HighscoreManager manager = new HighscoreManager();
        double avgTime = manager.getAverageTime("Puzzle1");

        assertEquals(-1, avgTime, "Average time should be -1 for no entries.");
    }

    @Test
    void testLoadSinglePuzzleFileNotFound() {
        HighscoreManager manager = new HighscoreManager();

        assertDoesNotThrow(() -> manager.loadSinglePuzzle("Puzzle1", "nonexistent.txt"));
        assertTrue(manager.getHighscores("Puzzle1").isEmpty());
    }
}